@@ -2,5 +2,5 @@ from optparse import Option
 from typing import Optional
 
 
-def load_dotenv_vault():
+def load_dotenv():
     print('loading dotenv-vault.')
\ No newline at end of file
